@@ -252,10 +252,7 @@ class DimensionCoordinate(
         :Parameters:
 
             args: sequence of numbers
-                A sequence of three numeric values. The first two values in the
-                sequence represent the coordinate range (see the bounds
-                parameter for details), and the third value represents the
-                cellsize.
+                {{regular args}}
 
             bounds: `bool`, optional
                 If True (the default) then the given range represents
@@ -311,12 +308,6 @@ class DimensionCoordinate(
                 f"negative cellsize ({cellsize})"
             )
 
-        if range_diff % cellsize != 0:
-            raise ValueError(
-                f"The range of the dimension ({range_diff}) must be "
-                f"divisible by the cellsize ({cellsize})"
-            )
-
         if standard_name is not None and not isinstance(standard_name, str):
             raise ValueError("standard_name must be either None or a string.")
 
