@@ -1,6 +1,8 @@
+import atexit
 import datetime
 import faulthandler
 import os
+import tempfile
 import unittest
 
 faulthandler.enable()  # to debug seg faults and timeouts
@@ -9,6 +11,26 @@ import numpy as np
 
 import cf
 
+n_tmpfiles = 1
+tmpfiles = [
+    tempfile.mkstemp("_test_regrid.nc", dir=os.getcwd())[1]
+    for i in range(n_tmpfiles)
+]
+(tmpfile,) = tmpfiles
+
+
+def _remove_tmpfiles():
+    """Try to remove defined temporary files by deleting their paths."""
+    for f in tmpfiles:
+        try:
+            os.remove(f)
+        except OSError:
+            pass
+
+
+atexit.register(_remove_tmpfiles)
+
+
 # ESMF renamed its Python module to `esmpy` at ESMF version 8.4.0. Allow
 # either for now for backwards compatibility.
 esmpy_imported = False
@@ -226,6 +248,7 @@ class RegridTest(unittest.TestCase):
 
                         if isinstance(a, np.ma.MaskedArray):
                             self.assertTrue((y.mask == a.mask).all())
+
                         else:
                             self.assertFalse(y.mask.any())
 
@@ -713,6 +736,47 @@ class RegridTest(unittest.TestCase):
             with self.assertRaises(ValueError):
                 src.regridc(dst, method=method, axes=axes)
 
+    @unittest.skipUnless(esmpy_imported, "Requires esmpy/ESMF package.")
+    def test_Field_regrid_chunks(self):
+        """Regridding of chunked axes"""
+        filename = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)), "regrid.nc"
+        )
+        dst, src = cf.read(filename, chunks={"latitude": 20, "longitude": 30})
+        self.assertEqual(src.data.numblocks, (1, 2, 2))
+        self.assertEqual(dst.data.numblocks, (1, 4, 4))
+
+        d0 = src.regrids(dst, method="linear")
+        self.assertEqual(d0.data.numblocks, (1, 1, 1))
+
+    @unittest.skipUnless(esmpy_imported, "Requires esmpy/ESMF package.")
+    def test_Field_regrid_weights_file(self):
+        """Regridding creation/use of weights file"""
+        dst = self.dst
+        src = self.src
+
+        try:
+            os.remove(tmpfile)
+        except OSError:
+            pass
+
+        r = src.regrids(
+            dst, method="linear", return_operator=True, weights_file=tmpfile
+        )
+        self.assertTrue(os.path.isfile(tmpfile))
+        self.assertIsNone(r.weights_file)
+
+        r = src.regrids(
+            dst, method="linear", return_operator=True, weights_file=tmpfile
+        )
+        self.assertEqual(r.weights_file, tmpfile)
+
+        # Can't provide weights_file when dst is a RegridOperator
+        with self.assertRaises(ValueError):
+            self.assertEqual(
+                src.regrids(r, method="linear", weights_file=tmpfile)
+            )
+
 
 if __name__ == "__main__":
     print("Run date:", datetime.datetime.now())
